@@ -109,11 +109,26 @@ class DocumentField:
     def __next__(self):
         try:
             result = list(self.__parent_dict.keys())[self.__index]
-            self._index += 1
+            self.__index += 1
             return result
         except IndexError:
             raise StopIteration()
 
+    def keys(self):
+        return self.__parent_dict.keys()
+
+    def items(self):
+        result = {}
+        for key in self.__parent_dict:
+            result[key] = self[key]
+        return result.items()
+
+    def get(self, key, default=None):
+        try:
+            return self[key]
+        except KeyError:
+            return default
+
 
 class DocumentArrayField:
 
